@@ -45,7 +45,7 @@ cat both_low.fa b_low.fa | awk -v RS='>' '{if($1 == "S1")print ">"$0 > "S1_low.f
 andi -j S0_low.fa S1_low.fa 2>&1 | grep 'homology'
 EXIT_VAL=$?
 
-if [[ EXIT_VAL -ge 1 ]]; then
+if [ ${EXIT_VAL} -ge 1 ]; then
 	echo "Triggering low homology failed" >&2
 	grep '^>' a_low.fa b_low.fa both_low.fa
 fi
